.. _module_hydra_lib_number:

number
======

This sections contains module documentation of number modules.

conversion
^^^^^^^^^^

Module provides number conversion methods.
Unit tests available at hydratk/lib/number/conversion/01_methods_ut.jedi

* int2bool

Method converts number to bool (True when > 1, False otherwise).